==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/services/licensemanager/CfnGrantProps.java <==
package software.amazon.awscdk.services.licensemanager;

/**
 * Properties for defining a `CfnGrant`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.licensemanager.*;
 * CfnGrantProps cfnGrantProps = CfnGrantProps.builder()
 *         .allowedOperations(List.of("allowedOperations"))
 *         .grantName("grantName")
 *         .homeRegion("homeRegion")
 *         .licenseArn("licenseArn")
 *         .principals(List.of("principals"))
 *         .status("status")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:13.272Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_licensemanager.CfnGrantProps")
@software.amazon.jsii.Jsii.Proxy(CfnGrantProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnGrantProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Allowed operations for the grant.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getAllowedOperations() {
        return null;
    }

    /**
     * Grant name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getGrantName() {
        return null;
    }

    /**
     * Home Region of the grant.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getHomeRegion() {
        return null;
    }

    /**
     * License ARN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getLicenseArn() {
        return null;
    }

    /**
     * The grant principals.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getPrincipals() {
        return null;
    }

    /**
     * Granted license status.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getStatus() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnGrantProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnGrantProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnGrantProps> {
        java.util.List<java.lang.String> allowedOperations;
        java.lang.String grantName;
        java.lang.String homeRegion;
        java.lang.String licenseArn;
        java.util.List<java.lang.String> principals;
        java.lang.String status;

        /**
         * Sets the value of {@link CfnGrantProps#getAllowedOperations}
         * @param allowedOperations Allowed operations for the grant.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder allowedOperations(java.util.List<java.lang.String> allowedOperations) {
            this.allowedOperations = allowedOperations;
            return this;
        }

        /**
         * Sets the value of {@link CfnGrantProps#getGrantName}
         * @param grantName Grant name.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder grantName(java.lang.String grantName) {
            this.grantName = grantName;
            return this;
        }

        /**
         * Sets the value of {@link CfnGrantProps#getHomeRegion}
         * @param homeRegion Home Region of the grant.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder homeRegion(java.lang.String homeRegion) {
            this.homeRegion = homeRegion;
            return this;
        }

        /**
         * Sets the value of {@link CfnGrantProps#getLicenseArn}
         * @param licenseArn License ARN.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder licenseArn(java.lang.String licenseArn) {
            this.licenseArn = licenseArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnGrantProps#getPrincipals}
         * @param principals The grant principals.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder principals(java.util.List<java.lang.String> principals) {
            this.principals = principals;
            return this;
        }

        /**
         * Sets the value of {@link CfnGrantProps#getStatus}
         * @param status Granted license status.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder status(java.lang.String status) {
            this.status = status;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnGrantProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnGrantProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnGrantProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnGrantProps {
        private final java.util.List<java.lang.String> allowedOperations;
        private final java.lang.String grantName;
        private final java.lang.String homeRegion;
        private final java.lang.String licenseArn;
        private final java.util.List<java.lang.String> principals;
        private final java.lang.String status;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.allowedOperations = software.amazon.jsii.Kernel.get(this, "allowedOperations", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.grantName = software.amazon.jsii.Kernel.get(this, "grantName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.homeRegion = software.amazon.jsii.Kernel.get(this, "homeRegion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.licenseArn = software.amazon.jsii.Kernel.get(this, "licenseArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.principals = software.amazon.jsii.Kernel.get(this, "principals", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.status = software.amazon.jsii.Kernel.get(this, "status", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.allowedOperations = builder.allowedOperations;
            this.grantName = builder.grantName;
            this.homeRegion = builder.homeRegion;
            this.licenseArn = builder.licenseArn;
            this.principals = builder.principals;
            this.status = builder.status;
        }

        @Override
        public final java.util.List<java.lang.String> getAllowedOperations() {
            return this.allowedOperations;
        }

        @Override
        public final java.lang.String getGrantName() {
            return this.grantName;
        }

        @Override
        public final java.lang.String getHomeRegion() {
            return this.homeRegion;
        }

        @Override
        public final java.lang.String getLicenseArn() {
            return this.licenseArn;
        }

        @Override
        public final java.util.List<java.lang.String> getPrincipals() {
            return this.principals;
        }

        @Override
        public final java.lang.String getStatus() {
            return this.status;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAllowedOperations() != null) {
                data.set("allowedOperations", om.valueToTree(this.getAllowedOperations()));
            }
            if (this.getGrantName() != null) {
                data.set("grantName", om.valueToTree(this.getGrantName()));
            }
            if (this.getHomeRegion() != null) {
                data.set("homeRegion", om.valueToTree(this.getHomeRegion()));
            }
            if (this.getLicenseArn() != null) {
                data.set("licenseArn", om.valueToTree(this.getLicenseArn()));
            }
            if (this.getPrincipals() != null) {
                data.set("principals", om.valueToTree(this.getPrincipals()));
            }
            if (this.getStatus() != null) {
                data.set("status", om.valueToTree(this.getStatus()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_licensemanager.CfnGrantProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnGrantProps.Jsii$Proxy that = (CfnGrantProps.Jsii$Proxy) o;

            if (this.allowedOperations != null ? !this.allowedOperations.equals(that.allowedOperations) : that.allowedOperations != null) return false;
            if (this.grantName != null ? !this.grantName.equals(that.grantName) : that.grantName != null) return false;
            if (this.homeRegion != null ? !this.homeRegion.equals(that.homeRegion) : that.homeRegion != null) return false;
            if (this.licenseArn != null ? !this.licenseArn.equals(that.licenseArn) : that.licenseArn != null) return false;
            if (this.principals != null ? !this.principals.equals(that.principals) : that.principals != null) return false;
            return this.status != null ? this.status.equals(that.status) : that.status == null;
        }

        @Override
        public final int hashCode() {
            int result = this.allowedOperations != null ? this.allowedOperations.hashCode() : 0;
            result = 31 * result + (this.grantName != null ? this.grantName.hashCode() : 0);
            result = 31 * result + (this.homeRegion != null ? this.homeRegion.hashCode() : 0);
            result = 31 * result + (this.licenseArn != null ? this.licenseArn.hashCode() : 0);
            result = 31 * result + (this.principals != null ? this.principals.hashCode() : 0);
            result = 31 * result + (this.status != null ? this.status.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/services/licensemanager/CfnGrantProps.java <==
package software.amazon.awscdk.services.licensemanager;

/**
 * Properties for defining a <code>CfnGrant</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.licensemanager.*;
 * CfnGrantProps cfnGrantProps = CfnGrantProps.builder()
 *         .allowedOperations(List.of("allowedOperations"))
 *         .grantName("grantName")
 *         .homeRegion("homeRegion")
 *         .licenseArn("licenseArn")
 *         .principals(List.of("principals"))
 *         .status("status")
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:34.749Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_licensemanager.CfnGrantProps")
@software.amazon.jsii.Jsii.Proxy(CfnGrantProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnGrantProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Allowed operations for the grant.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-allowedoperations">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-allowedoperations</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getAllowedOperations() {
        return null;
    }

    /**
     * Grant name.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-grantname">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-grantname</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getGrantName() {
        return null;
    }

    /**
     * Home Region of the grant.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-homeregion">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-homeregion</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getHomeRegion() {
        return null;
    }

    /**
     * License ARN.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-licensearn">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-licensearn</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getLicenseArn() {
        return null;
    }

    /**
     * The grant principals. You can specify one of the following as an Amazon Resource Name (ARN):.
     * <p>
     * <ul>
     * <li>An AWS account, which includes only the account specified.</li>
     * <li>An organizational unit (OU), which includes all accounts in the OU.</li>
     * <li>An organization, which will include all accounts across your organization.</li>
     * </ul>
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-principals">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-principals</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getPrincipals() {
        return null;
    }

    /**
     * Granted license status.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-status">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-licensemanager-grant.html#cfn-licensemanager-grant-status</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getStatus() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnGrantProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnGrantProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnGrantProps> {
        java.util.List<java.lang.String> allowedOperations;
        java.lang.String grantName;
        java.lang.String homeRegion;
        java.lang.String licenseArn;
        java.util.List<java.lang.String> principals;
        java.lang.String status;

        /**
         * Sets the value of {@link CfnGrantProps#getAllowedOperations}
         * @param allowedOperations Allowed operations for the grant.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder allowedOperations(java.util.List<java.lang.String> allowedOperations) {
            this.allowedOperations = allowedOperations;
            return this;
        }

        /**
         * Sets the value of {@link CfnGrantProps#getGrantName}
         * @param grantName Grant name.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder grantName(java.lang.String grantName) {
            this.grantName = grantName;
            return this;
        }

        /**
         * Sets the value of {@link CfnGrantProps#getHomeRegion}
         * @param homeRegion Home Region of the grant.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder homeRegion(java.lang.String homeRegion) {
            this.homeRegion = homeRegion;
            return this;
        }

        /**
         * Sets the value of {@link CfnGrantProps#getLicenseArn}
         * @param licenseArn License ARN.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder licenseArn(java.lang.String licenseArn) {
            this.licenseArn = licenseArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnGrantProps#getPrincipals}
         * @param principals The grant principals. You can specify one of the following as an Amazon Resource Name (ARN):.
         *                   <ul>
         *                   <li>An AWS account, which includes only the account specified.</li>
         *                   <li>An organizational unit (OU), which includes all accounts in the OU.</li>
         *                   <li>An organization, which will include all accounts across your organization.</li>
         *                   </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder principals(java.util.List<java.lang.String> principals) {
            this.principals = principals;
            return this;
        }

        /**
         * Sets the value of {@link CfnGrantProps#getStatus}
         * @param status Granted license status.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder status(java.lang.String status) {
            this.status = status;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnGrantProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnGrantProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnGrantProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnGrantProps {
        private final java.util.List<java.lang.String> allowedOperations;
        private final java.lang.String grantName;
        private final java.lang.String homeRegion;
        private final java.lang.String licenseArn;
        private final java.util.List<java.lang.String> principals;
        private final java.lang.String status;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.allowedOperations = software.amazon.jsii.Kernel.get(this, "allowedOperations", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.grantName = software.amazon.jsii.Kernel.get(this, "grantName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.homeRegion = software.amazon.jsii.Kernel.get(this, "homeRegion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.licenseArn = software.amazon.jsii.Kernel.get(this, "licenseArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.principals = software.amazon.jsii.Kernel.get(this, "principals", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.status = software.amazon.jsii.Kernel.get(this, "status", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.allowedOperations = builder.allowedOperations;
            this.grantName = builder.grantName;
            this.homeRegion = builder.homeRegion;
            this.licenseArn = builder.licenseArn;
            this.principals = builder.principals;
            this.status = builder.status;
        }

        @Override
        public final java.util.List<java.lang.String> getAllowedOperations() {
            return this.allowedOperations;
        }

        @Override
        public final java.lang.String getGrantName() {
            return this.grantName;
        }

        @Override
        public final java.lang.String getHomeRegion() {
            return this.homeRegion;
        }

        @Override
        public final java.lang.String getLicenseArn() {
            return this.licenseArn;
        }

        @Override
        public final java.util.List<java.lang.String> getPrincipals() {
            return this.principals;
        }

        @Override
        public final java.lang.String getStatus() {
            return this.status;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAllowedOperations() != null) {
                data.set("allowedOperations", om.valueToTree(this.getAllowedOperations()));
            }
            if (this.getGrantName() != null) {
                data.set("grantName", om.valueToTree(this.getGrantName()));
            }
            if (this.getHomeRegion() != null) {
                data.set("homeRegion", om.valueToTree(this.getHomeRegion()));
            }
            if (this.getLicenseArn() != null) {
                data.set("licenseArn", om.valueToTree(this.getLicenseArn()));
            }
            if (this.getPrincipals() != null) {
                data.set("principals", om.valueToTree(this.getPrincipals()));
            }
            if (this.getStatus() != null) {
                data.set("status", om.valueToTree(this.getStatus()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_licensemanager.CfnGrantProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnGrantProps.Jsii$Proxy that = (CfnGrantProps.Jsii$Proxy) o;

            if (this.allowedOperations != null ? !this.allowedOperations.equals(that.allowedOperations) : that.allowedOperations != null) return false;
            if (this.grantName != null ? !this.grantName.equals(that.grantName) : that.grantName != null) return false;
            if (this.homeRegion != null ? !this.homeRegion.equals(that.homeRegion) : that.homeRegion != null) return false;
            if (this.licenseArn != null ? !this.licenseArn.equals(that.licenseArn) : that.licenseArn != null) return false;
            if (this.principals != null ? !this.principals.equals(that.principals) : that.principals != null) return false;
            return this.status != null ? this.status.equals(that.status) : that.status == null;
        }

        @Override
        public final int hashCode() {
            int result = this.allowedOperations != null ? this.allowedOperations.hashCode() : 0;
            result = 31 * result + (this.grantName != null ? this.grantName.hashCode() : 0);
            result = 31 * result + (this.homeRegion != null ? this.homeRegion.hashCode() : 0);
            result = 31 * result + (this.licenseArn != null ? this.licenseArn.hashCode() : 0);
            result = 31 * result + (this.principals != null ? this.principals.hashCode() : 0);
            result = 31 * result + (this.status != null ? this.status.hashCode() : 0);
            return result;
        }
    }
}
